add lastitem and adapt code to general code style
[xmenu] / xmenu.h
diff --git a/xmenu.h b/xmenu.h
index 93a3fd7..e29df02 100644 (file)
--- a/xmenu.h
+++ b/xmenu.h
@@ -1,8 +1,7 @@
 #define PROGNAME "xmenu"
 
 #define PROGNAME "xmenu"
 
-/* macros for keyboard menu navigation */
-#define ITEMPREV 0
-#define ITEMNEXT 1
+/* enum for keyboard menu navigation */
+enum { ITEMPREV, ITEMNEXT, ITEMFIRST, ITEMLAST };
 
 /* macros */
 #define LEN(x)              (sizeof (x) / sizeof (x[0]))
 
 /* macros */
 #define LEN(x)              (sizeof (x) / sizeof (x[0]))
@@ -53,6 +52,7 @@ struct DC {
 
        GC gc;
 
 
        GC gc;
 
+       FcPattern *pattern;
        XftFont **fonts;
        size_t nfonts;
 };
        XftFont **fonts;
        size_t nfonts;
 };
@@ -71,7 +71,7 @@ struct Item {
        Imlib_Image icon;
 };
 
        Imlib_Image icon;
 };
 
-/* monitor and cursor geometry structure */
+/* monitor geometry structure */
 struct Monitor {
        int x, y, w, h;         /* monitor geometry */
 };
 struct Monitor {
        int x, y, w, h;         /* monitor geometry */
 };